Welcome to UEVaultManager
==========================================
![UEVM_200x200.png](UEVaultManager%2Fassets%2FUEVM_200x200.png)

| pypi                                                                                                                 | py_versions                                                                                                          | github                                                                                                                         | docs                                                                                                                               |
|----------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------|
| [![Current PyPi Version](https://img.shields.io/pypi/v/uevaultmanager)](https://pypi.python.org/pypi/uevaultmanager) | [![py_versions](https://img.shields.io/pypi/pyversions/uevaultmanager)](https://pypi.python.org/pypi/uevaultmanager) | [![github](https://img.shields.io/github/v/tag/LaurentOngaro/uevaultmanager)](https://github.com/LaurentOngaro/UEVaultManager) | [![docs](https://img.shields.io/readthedocs/uevaultmanager/latest)](https://uevaultmanager.readthedocs.io/en/latest/?badge=latest) |

**UEVaultManager** is an open-source assets manager that can list assets and
their data from the Epic Games Marketplace. It is developed in Python, so
it can run on any platform that support this language.

Its main purpose is to list the assets (with or without user login),
filter (optional) and save the list into a file that can be reused later
as a data source (in an Excel sheet for instance).

**This project is under active development**

To go further, dive into [the documentation](https://uevaultmanager.readthedocs.io/en/latest/index.html) or just go
for [a quickstart](https://uevaultmanager.readthedocs.io/en/latest/quickstart.html)

Contents:

* [UEVaultManager](https://uevaultmanager.readthedocs.io/en/latest/intro.html)
  * [A free and open-source Epic Games Assets Manager for Unreal Engine](https://uevaultmanager.readthedocs.io/en/latest/intro.html#a-free-and-open-source-epic-games-assets-manager-for-unreal-engine)
  * [Known bugs and limitations](https://uevaultmanager.readthedocs.io/en/latest/intro.html#known-bugs-and-limitations)
* [Quickstart](https://uevaultmanager.readthedocs.io/en/latest/quickstart.html)
  * [Installation](https://uevaultmanager.readthedocs.io/en/latest/quickstart.html#installation)
  * [log in](https://uevaultmanager.readthedocs.io/en/latest/quickstart.html#log-in)
  * [Listing your asset](https://uevaultmanager.readthedocs.io/en/latest/quickstart.html#listing-your-asset)
  * [Saving the list into a CSV file](https://uevaultmanager.readthedocs.io/en/latest/quickstart.html#saving-the-list-into-a-csv-file)
* [How to run/install](https://uevaultmanager.readthedocs.io/en/latest/setup.html)
  * [Requirements](https://uevaultmanager.readthedocs.io/en/latest/setup.html#requirements)
  * [Prerequisites](https://uevaultmanager.readthedocs.io/en/latest/setup.html#prerequisites)
  * [Directly from the repo](https://uevaultmanager.readthedocs.io/en/latest/setup.html#directly-from-the-repo)
  * [Direct installation (any)](https://uevaultmanager.readthedocs.io/en/latest/setup.html#direct-installation-any)
* [Usage](https://uevaultmanager.readthedocs.io/en/latest/usage.html)
* [Configuration](https://uevaultmanager.readthedocs.io/en/latest/configuration.html)
  * [Config folder](https://uevaultmanager.readthedocs.io/en/latest/configuration.html#config-folder)
  * [Config file](https://uevaultmanager.readthedocs.io/en/latest/configuration.html#config-file)
* [Output Format and file](https://uevaultmanager.readthedocs.io/en/latest/output.html)
  * [Log files and debug](https://uevaultmanager.readthedocs.io/en/latest/output.html#log-files-and-debug)
  * [The output file](https://uevaultmanager.readthedocs.io/en/latest/output.html#the-output-file)
  * [The individual json files](https://uevaultmanager.readthedocs.io/en/latest/output.html#the-individual-json-files)
  * [how to fix invalid search result during the grabbing process](https://uevaultmanager.readthedocs.io/en/latest/output.html#how-to-fix-invalid-search-result-during-the-grabbing-process)
  * [possible values in the error Field](https://uevaultmanager.readthedocs.io/en/latest/output.html#possible-values-in-the-error-field)

[Next](https://uevaultmanager.readthedocs.io/en/latest/intro.html "UEVaultManager")
